TITLE Choose.asm
;                                      ====================
;=======================================    Choose.asm    ==========================================
;==                                    ====================                                       ==
;==                                                                                               ==
;== Project         : Scangui                                                                     ==
;== Filename        : Choose.asm                                                                  ==
;== Version         : 1                                                                           ==
;== Date            : Jul 15, 2008                                                                 ==
;== Compiler        : Masm v. 6.14 by Microsoft Corporation.                                      ==
;== Purpose         : Lets user to choose a source file to be scanned for functions.              ==
;==                                                                                               ==
;===================================================================================================
;==                                                                                               ==
;== Copyright (c) 2008, P. H. Duarte                                                              ==
;== All rights reserved.                                                                          ==
;==                                                                                               ==
;===================================================================================================

; VERSION HISTORY:
; ----------------

; Version           : 1
; Date              : Jul 15, 2008
; Revised by        : P. H. Duarte
; Description       : Original Version.
;===================================================================================================

.686
.model flat, stdcall
option casemap:none

;===================================================================================================
;=                                 Exported Symbols and functions                                 =
;===================================================================================================

Choose EQU 1
PUBLIC ChooseFile
PUBLIC lpstrFile

;===================================================================================================
;=                                 Include Files                                                   =
;===================================================================================================

include ScanGII.inc

;===================================================================================================
;=                                 Local Data                                                      =
;===================================================================================================

.data

; --> OpenFileName data. <--

szImpExt					TCHAR	"imp", 0			; Default filename extension.
szFilter 					TCHAR	"Assembly (*.asm)", 0, "*.asm", 0
							TCHAR	"Include (*.inc)", 0, "*.inc", 0
 							TCHAR	"All files", 0, "*.*", 0, 0
lpstrFile					TCHAR	MAXLEN 		DUP (0) ; Buffer for source file name.
lpstrFileTitle				TCHAR	MAXLEN		DUP (0) ;
szTitle						TCHAR	"Select file to scan:", 0 ; OpenFileName box title.

ofn		  	OPENFILENAME		<SIZEOF OPENFILENAME, \
								NULL, \
								NULL, \
								OFFSET szFilter, \
		  						NULL, \
		  						NULL, \
		  						NULL, \
		  						OFFSET lpstrFile, \
		  						MAXLEN, \
		  						OFFSET lpstrFileTitle, \
		  						MAXLEN, \
		  						NULL, \
		  						OFFSET szTitle, \
		  						uFlagsOfn, \
		  						NULL, \
		  						NULL, \
		  						NULL, \
		  						NULL, \
		  						NULL, \
		  						NULL>

;===================================================================================================		

.code

;===================================================================================================
;
; ChooseFile (hwnd)
;
; PURPOSE:	Choose the source file to be scanned.
;
; ENTRY:	hwnd  = Handle to main window.
;
; EXIT:		EAX:
;				Holds the message ID for any of the following:
;				ID_ST_INVALIDNAME 		= Invalid name.
;				ID_ST_HAVENOTSELECTED 	= No file. 
;									0 	= No error.
;				lpstrFileTitle			= The source file name.
;				szOutName				= Importations file.
;
;===================================================================================================

ChooseFile proc hwnd:HWND
align 04	
	push dword ptr ds:[hwnd]
	pop dword ptr ds:[ofn.hwndOwner]
	invoke GetOpenFileName, offset ofn
	.if EAX == 0
		mov EAX, ID_ST_HAVENOTSELECTED 	; No file to scan.	
	.else
		mov ECX, MAXLEN 				 
		mov EDI, offset szOutName 		; EDI -> File of imported functions.
		push EDI 						 
		mov ESI, offset lpstrFileTitle 	; ESI -> Name of source file.
		
		cld
		rep movsb						
		
; --> Changes the filename extension. <--
		
		pop EDI 					
		mov AL, "." 				; Al  -> Holds the delimiter character.
		and EAX, 000000FFh				 
		.repeat
			
			inc EDI 
			.if byte ptr ds:[EDI] == 0
				mov EAX, ID_ST_INVALIDNAME ; Invalid name: '.' not found.
				jmp Escolhefinish
			.endif
			
		.until byte ptr ds:[EDI] == AL	
		inc EDI 						; EDI is one unit higher than we need.
		
; --> Copies imp to correct place and changes the filename extension. <--
		
		mov ESI, offset szImpExt			; ESI -> "imp". 		
		mov ECX, 03
		cld
		rep movsb
		xor EAX, EAX
	.endif
Escolhefinish:
	ret
	
ChooseFile endp
end

;===================================================================================================
;=                                             EOF                                                 =
;===================================================================================================