;                                      ====================
;=======================================    Verify.asm    ==========================================
;==                                    ====================                                       ==
;==                                                                                               ==
;== Project         : ScanGui                                                                     ==
;== Filename        : Verify.asm                                                                  ==
;== Version         : 1                                                                           ==
;== Date            : Jul 15, 2008                                                                 ==
;== Compiler        : Masm v. 6.14 by Microsoft Corporation.                                      ==
;== Purpose         : Check parameters to send a correct command line to scan.                    ==
;==                                                                                               ==
;===================================================================================================
;==                                                                                               ==
;== Copyright (c) 2008, P. H. Duarte                                                              ==
;== All rights reserved.                                                                          ==
;==                                                                                               ==
;===================================================================================================

; VERSION HISTORY:
; ----------------

; Version           : 1
; Date              : Jul 15, 2008
; Revised by        : P. H. Duarte
; Description       : Original Version.
;===================================================================================================

.686
.model flat, stdcall
option casemap:none

;===================================================================================================
;=                                     Exported Symbols and functions                              =
;===================================================================================================

PUBLIC Verify

;===================================================================================================
;=                                     Include Files                                               =
;===================================================================================================

include ScanGII.inc

;===================================================================================================
 
.code

;===================================================================================================
;
; Function Verify (hwnd )
;
; Purpose: Verifies parameters to be pass in command line for scan.exe  
;
; Entry:		hwnd	= Handle to main window.
;
; Description:	This function searches for '\' character in the source file name from the end of
;				the string to its 'zero point'. It doesn't verify the existence of any file!!!
;				It still checks and sets the correct extra options in the check box controls of 
;				program.
;				To do so, this function reads the edit boxes contents, the check box contents and
;				stores the last result in the correct variable (bOptions). 
;
; Returns:		Error code in EAX, if any.		
;
; Error Handling: NA
;===================================================================================================

Verify PROC hwnd:HWND
	align 04

; Verifies edit box for source file name. 
	invoke GetDlgItemText, dword ptr ds:[hwnd], EDT_1, addr lpstrFile, MAXLEN
	
	.if EAX == 0
		mov EAX, ID_ST_HAVENOTSELECTED
		
;  Verifies valid file name. 
;  File name must have a '\' in its string. 
	.else	
		xchg EAX, ECX			; ECX -> Lenght of file name string.
		push offset lpstrFile
		pop EDI					; EDI -> Start point of string.
		add EDI, ECX			; EDI -> End point of string.
		std						
		and ECX, 0ffffh			; ECX -> Lenght of lpstrFile.
		mov al, '\'				; Search for '\' in file name.
		and EAX, 0ffh
		repne scasb
		or ECX, ECX
		jnz @f					
		mov EAX, ID_ST_INVALIDNAME ; The file name is invalid.
		ret
@@:
		inc ECX
		inc ECX
		push offset lpstrFile
		pop ESI
		mov EDI, offset lpstrFilePath
		cld						; Copies forward
		rep movsb
		 				
		
		invoke GetDlgItemText, dword ptr ds:[hwnd], EDT_2, addr  szOutName, MAXLEN
		.if EAX == 0
			mov EAX, ID_ST_NOTOUTPUTNAME	; No name for importation file. 
			ret          	
		.endif                          	
		                                	
; Verifies check buttons.            	
		mov EBX, CHK_1 					; EBX -> Check buttons control counter.
		.while EBX <= CHK_3             	
			push EBX                    	
			invoke GetDlgItem, dword ptr ds:[hwnd], EBX
			mov dword ptr ds:[hCheck], EAX
			invoke SendMessage, dword ptr ds:[hCheck], BM_GETCHECK, NULL, NULL 
			and EAX, 0ffh 
			sub EBX, CHK_1
			mov byte ptr ds:[bOptions + EBX], AL	; Stores check button state.
			pop EBX                             	
			inc EBX
		.endw
		xor EAX, EAX
	.endif
	
	ret
Verify endp			
end
;===================================================================================================
;=                                             EOF                                                 =
;===================================================================================================